pub enum MetaItem {
Expr(MetaExpr),
KeyValue(Ident, MetaExpr),
}Expand description
Represents a single metadata item provided as an argument to an attribute.
For example, the foo attribute in @foo(bar, baz) has two metadata items, both of Expr
type, which compose a `
Variants
Expr(MetaExpr)
A metadata expression, e.g. "some text" in @foo("some text")
This represents the element type for Meta::List-based attributes.
KeyValue(Ident, MetaExpr)
A named metadata expression, e.g. letter = a in @foo(letter = a)
This represents the element type for Meta::KeyValue-based attributes.
Implementations
Sourceimpl MetaItem
impl MetaItem
Sourcepub fn unwrap_expr(self) -> MetaExpr
pub fn unwrap_expr(self) -> MetaExpr
Unwrap this item to extract the contained MetaExpr.
Panics if this item is not the Expr variant.
Sourcepub fn unwrap_key_value(self) -> (Ident, MetaExpr)
pub fn unwrap_key_value(self) -> (Ident, MetaExpr)
Unwrap this item to extract the contained key-value pair.
Panics if this item is not the KeyValue variant.