pub enum SymbolResolution {
Local(Span<ItemIndex>),
External(Span<Arc<Path>>),
MastRoot(Span<Word>),
Exact {
gid: GlobalItemIndex,
path: Span<Arc<Path>>,
},
Module {
id: ModuleIndex,
path: Span<Arc<Path>>,
},
}Expand description
Represents the result of resolving a symbol
Variants
Local(Span<ItemIndex>)
The name was resolved to a definition in the same module at the given index
External(Span<Arc<Path>>)
The name was resolved to a path referring to an item exported from another module
MastRoot(Span<Word>)
The name was resolved to a procedure MAST root
Exact
The name was resolved to a known definition in with the given global index and absolute path
Module
The name was resolved to a known module
Implementations
Sourceimpl SymbolResolution
impl SymbolResolution
pub fn into_global_id(&self) -> Option<GlobalItemIndex>