pub fn constant_path_random_length(min: u8) -> impl Strategy<Value = Arc<Path>>Expand description
Generate a Arc<Path> of random length, but at least min prefix components, that is
valid for use with constant items.
The returned PathBuf will always have at least one component, the name of the constant.