pub struct LocalSymbolResolver { /* private fields */ }Expand description
A resolver for symbol references in the context of some module.
This resolver does not attempt to resolve external references, aside from expanding any uses of imports in an external path.
This is used as a low-level symbol resolution primitive in the linker as well.
Implementations
Sourceimpl LocalSymbolResolver
impl LocalSymbolResolver
Sourcepub fn new<S>(
symbols: S,
source_manager: Arc<dyn SourceManager>,
) -> Result<Self, SymbolResolutionError>where
S: SymbolTable,
pub fn new<S>(
symbols: S,
source_manager: Arc<dyn SourceManager>,
) -> Result<Self, SymbolResolutionError>where
S: SymbolTable,
Create a new resolver using the provided SymbolTable and SourceManager.
pub fn source_manager(&self) -> Arc<dyn SourceManager>
Sourcepub fn resolve(
&self,
name: Span<&str>,
) -> Result<SymbolResolution, SymbolResolutionError>
pub fn resolve( &self, name: Span<&str>, ) -> Result<SymbolResolution, SymbolResolutionError>
Try to resolve name to an item, either local or external
See SymbolTable::get for details.
Sourcepub fn resolve_path(
&self,
path: Span<&Path>,
) -> Result<SymbolResolution, SymbolResolutionError>
pub fn resolve_path( &self, path: Span<&Path>, ) -> Result<SymbolResolution, SymbolResolutionError>
Try to resolve path to an item, either local or external
Sourcepub fn get_item_name(&self, index: ItemIndex) -> Ident
pub fn get_item_name(&self, index: ItemIndex) -> Ident
Get the name of the item at index
This is guaranteed to resolve if index is valid, and will panic if not.