pub struct MetaKeyValue {
pub span: SourceSpan,
pub name: Ident,
pub items: BTreeMap<Ident, MetaExpr>,
}Expand description
Represents the metadata of a key-value crate::ast::Attribute, i.e. @props(key = value)
Fields
span: SourceSpanname: IdentThe name of the key-value dictionary
items: BTreeMap<Ident, MetaExpr>The set of key-value pairs provided as arguments to this attribute
Implementations
Sourceimpl MetaKeyValue
impl MetaKeyValue
pub fn new<K, V, I>(name: Ident, items: I) -> Self
pub fn with_span(self, span: SourceSpan) -> Self
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if this metadata contains an entry for key
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&MetaExpr>
pub fn get<Q>(&self, key: &Q) -> Option<&MetaExpr>
Returns the value associated with key, if present in this metadata
Sourcepub fn insert(&mut self, key: impl Into<Ident>, value: impl Into<MetaExpr>)
pub fn insert(&mut self, key: impl Into<Ident>, value: impl Into<MetaExpr>)
Inserts a new key-value entry in this metadata
Sourcepub fn remove<Q>(&mut self, key: &Q) -> Option<MetaExpr>
pub fn remove<Q>(&mut self, key: &Q) -> Option<MetaExpr>
Removes the entry associated with key, if present in this metadata, and returns it