pub struct SubmoduleDecl {
pub visibility: Visibility,
pub name: Ident,
}Expand description
Represents a submodule declaration in a super::Module, i.e. mod foo or pub mod foo
Fields
visibility: VisibilityThe visibility of the submodule outside the containing namespace.
A private submodule is visible only to:
- It’s parent
- It’s siblings and their descendants
A public submodule is visible to everyone.
name: IdentThe name of the submodule
The full path of the submodule is derived from the path of its parent module