pub struct TypeAlias {
pub visibility: Visibility,
pub name: Ident,
pub ty: TypeExpr,
/* private fields */
}Expand description
A TypeAlias represents a named [Type].
Type aliases correspond to type declarations in Miden Assembly source files. They are called aliases, rather than declarations, as the type system for Miden Assembly is structural, rather than nominal, and so two aliases with the same underlying type are considered equivalent.
Fields
visibility: VisibilityThe visibility of this type alias
name: IdentThe name of this type alias
ty: TypeExprThe concrete underlying type
Implementations
Sourceimpl TypeAlias
impl TypeAlias
Sourcepub fn new(visibility: Visibility, name: Ident, ty: TypeExpr) -> Self
pub fn new(visibility: Visibility, name: Ident, ty: TypeExpr) -> Self
Create a new type alias from a name and type
Sourcepub fn with_docs(self, docs: Option<Span<String>>) -> Self
pub fn with_docs(self, docs: Option<Span<String>>) -> Self
Adds documentation to this type alias
Sourcepub const fn visibility(&self) -> Visibility
pub const fn visibility(&self) -> Visibility
Get the visibility of this type alias