pub struct Variant {
pub span: SourceSpan,
pub docs: Option<DocString>,
pub name: Ident,
pub value_ty: Option<TypeExpr>,
pub discriminant: ConstantExpr,
}Fields
span: SourceSpandocs: Option<DocString>The documentation string attached to the constant derived from this variant.
name: IdentThe name of this enum variant
value_ty: Option<TypeExpr>The payload value type of this variant
NOTE: This is not supported in Miden Assembly text format yet, but can be set when lowering directly to the AST.
discriminant: ConstantExprThe discriminant value associated with this variant
Implementations
Sourceimpl Variant
impl Variant
Sourcepub fn new(
name: Ident,
discriminant: ConstantExpr,
payload: Option<TypeExpr>,
) -> Self
pub fn new( name: Ident, discriminant: ConstantExpr, payload: Option<TypeExpr>, ) -> Self
Construct a new variant of an EnumType, with the given name and discriminant value.
Sourcepub fn with_span(self, span: SourceSpan) -> Self
pub fn with_span(self, span: SourceSpan) -> Self
Override the span for this variant
Sourcepub fn assert_instance_of(&self, ty: &Type) -> Result<(), SemanticAnalysisError>
pub fn assert_instance_of(&self, ty: &Type) -> Result<(), SemanticAnalysisError>
Used to validate that this variant’s discriminant value is an instance of ty,
which must be a type valid for use as the underlying representation for an enum, i.e. an
integer type up to 64 bits in size.
It is expected that the discriminant expression has been folded to an integer value by the time this is called. If the discriminant has not been fully folded, then an error will be returned.