Type Alias ImmFelt
Source pub type ImmFelt = Immediate<Felt>;
A field element immediate
pub enum ImmFelt {
Value(Span<Felt>),
Constant(Ident),
}
A literal integer value, either decimal or hex-encoded
A constant identifier
This must refer to a constant definition in the current module.
All immediates of this type are folded to Value during
semantic analysis, once all constant definitions are evaluated.