Type Alias ImmU16
Source pub type ImmU16 = Immediate<u16>;
A 16-bit unsigned immediate
pub enum ImmU16 {
Value(Span<u16>),
Constant(Ident),
}
A literal integer value, either decimal or hex-encoded
A constant identifier
This must refer to a constant definition in the current module.
All immediates of this type are folded to Value during
semantic analysis, once all constant definitions are evaluated.