Type Alias ImmU32
Source pub type ImmU32 = Immediate<u32>;
A 32-bit unsigned immediate
pub enum ImmU32 {
Value(Span<u32>),
Constant(Ident),
}
A literal integer value, either decimal or hex-encoded
A constant identifier
This must refer to a constant definition in the current module.
All immediates of this type are folded to Value during
semantic analysis, once all constant definitions are evaluated.