Type Alias ImmU8
Source pub type ImmU8 = Immediate<u8>;
An 8-bit unsigned immediate
pub enum ImmU8 {
Value(Span<u8>),
Constant(Ident),
}
A literal integer value, either decimal or hex-encoded
A constant identifier
This must refer to a constant definition in the current module.
All immediates of this type are folded to Value during
semantic analysis, once all constant definitions are evaluated.