The type system a MASM signature is written in.
The types themselves come from midenc_hir_type and are re-exported here. On top of them,
signatures converts between the values a signature names and the felts the VM stack holds.
Re-exports
pub use self::signatures::FeltCodec;pub use self::signatures::MIDEN_CORE_TYPES;pub use self::signatures::TypedError;pub use self::signatures::TypedProcInfo;pub use self::signatures::WitScalarCodec;pub use self::signatures::WordCodec;
Modules
- signatures
- A typed view of a procedure signature.
Structs
- Array
Type - A fixed-size, homogenous vector type.
- Enum
Type - An enum type is a special type that takes one of two forms:
- Function
Type - This represents the type of a function, i.e. it’s parameters and results, and expected calling convention.
- Name
AndType - A wrapper around Type which permits a Type to be optionally named.
- Pointer
Type - A pointer to an object in memory
- Struct
Field - This represents metadata about a field of a StructType
- Struct
Type - This represents a structured aggregate type
- Variant
Enums
- Address
Space - The address space a pointer address is evaluated in.
- Call
Conv - Represents the calling convention of a function.
- Invalid
Address Space Error - This error is raised when parsing an AddressSpace
- Invalid
Enum Type Error - The error type returned when attempting to construct an invalid EnumType
- Type
- Represents the type of a value in the HIR type system
- Type
Repr - This represents metadata about how a structured type will be represented in memory
Traits
- Alignable
- This trait represents an alignable primitive integer value representing an address