pub enum TypeRepr {
Default,
Align(NonZero<u16>),
Packed(NonZero<u16>),
Transparent,
}Expand description
This represents metadata about how a structured type will be represented in memory
Variants
Default
This corresponds to the C ABI representation for a given type
Align(NonZero<u16>)
This modifies the default representation, by raising the minimum alignment.
The alignment must be a power of two, e.g. 32, and values from 1 to 2^16 are allowed.
The alignment must be greater than the default minimum alignment of the type or this representation has no effect.
Packed(NonZero<u16>)
This modifies the default representation, by lowering the minimum alignment of a type, and in the case of structs, changes the alignments of the fields to be the smaller of the specified alignment and the default alignment. This has the effect of changing the layout of a struct.
Notably, Packed(1) will result in a struct that has no alignment requirement,
and no padding between fields.
The alignment must be a power of two, e.g. 32, and values from 1 to 2^16 are allowed.
The alignment must be smaller than the default alignment, or this representation has no effect.
Transparent
This may only be used on structs with no more than one non-zero sized field, and indicates that the representation of that field should be used for the struct.
Implementations
Sourceimpl TypeRepr
impl TypeRepr
Sourcepub fn packed(align: u16) -> TypeRepr
pub fn packed(align: u16) -> TypeRepr
Construct a packed representation with the given alignment
Sourcepub fn align(align: u16) -> TypeRepr
pub fn align(align: u16) -> TypeRepr
Construct a representation with the given minimum alignment
Sourcepub fn is_transparent(&self) -> bool
pub fn is_transparent(&self) -> bool
Return true if this type representation is transparent
Sourcepub fn min_alignment(&self) -> Option<usize>
pub fn min_alignment(&self) -> Option<usize>
Get the custom alignment given for this type representation, if applicable