pub enum TypeTemplate {
Type(Type),
Rec(Arc<str>),
Ptr(AddressSpace, Box<TypeTemplate>),
Array(Box<TypeTemplate>, usize),
List(Box<TypeTemplate>),
Function(Box<FunctionTemplate>),
Struct(Box<StructTemplate>),
Enum(Box<EnumTemplate>),
}Expand description
A type expression used while describing a recursive definition to RecursiveTypeBuilder.
Variants
Type(Type)
An ordinary, already-completed type.
Rec(Arc<str>)
A reference to a definition being built, by name.
Ptr(AddressSpace, Box<TypeTemplate>)
Array(Box<TypeTemplate>, usize)
List(Box<TypeTemplate>)
Function(Box<FunctionTemplate>)
Struct(Box<StructTemplate>)
Enum(Box<EnumTemplate>)
Implementations
Sourceimpl TypeTemplate
impl TypeTemplate
Sourcepub fn rec(name: impl Into<Arc<str>>) -> TypeTemplate
pub fn rec(name: impl Into<Arc<str>>) -> TypeTemplate
A reference to the definition named name.
Sourcepub fn ptr(pointee: impl Into<TypeTemplate>) -> TypeTemplate
pub fn ptr(pointee: impl Into<TypeTemplate>) -> TypeTemplate
A byte-addressable pointer to pointee.
Sourcepub fn ptr_in(
addrspace: AddressSpace,
pointee: impl Into<TypeTemplate>,
) -> TypeTemplate
pub fn ptr_in( addrspace: AddressSpace, pointee: impl Into<TypeTemplate>, ) -> TypeTemplate
A pointer to pointee in addrspace.
Sourcepub fn array(element: impl Into<TypeTemplate>, len: usize) -> TypeTemplate
pub fn array(element: impl Into<TypeTemplate>, len: usize) -> TypeTemplate
A fixed-length array of element.
Sourcepub fn list(element: impl Into<TypeTemplate>) -> TypeTemplate
pub fn list(element: impl Into<TypeTemplate>) -> TypeTemplate
A dynamically sized list of element.
Sourcepub fn function(
abi: CallConv,
params: impl IntoIterator<Item = TypeTemplate>,
results: impl IntoIterator<Item = TypeTemplate>,
) -> TypeTemplate
pub fn function( abi: CallConv, params: impl IntoIterator<Item = TypeTemplate>, results: impl IntoIterator<Item = TypeTemplate>, ) -> TypeTemplate
A function reference type.
Sourcepub fn struct_type(
repr: TypeRepr,
fields: impl IntoIterator<Item = FieldTemplate>,
) -> TypeTemplate
pub fn struct_type( repr: TypeRepr, fields: impl IntoIterator<Item = FieldTemplate>, ) -> TypeTemplate
An anonymous struct.