assert_diagnostic_lines

Macro assert_diagnostic_lines 

macro_rules! assert_diagnostic_lines {
    ($diagnostic:expr, $($expected_lines:expr),+) => { ... };
}
Like assert_diagnostic, but matches each non-empty line of the rendered output to a corresponding pattern.

Empty lines are ignored, but the remaining line count must match the number of patterns.