pub struct ModuleDescriptor { /* private fields */ }Expand description
Describes a MASM module surface, including its path, version, exports, and declared submodules.
Implementations
Sourceimpl ModuleDescriptor
impl ModuleDescriptor
Sourcepub fn new(path: Arc<Path>, version: Option<Version>) -> Self
pub fn new(path: Arc<Path>, version: Option<Version>) -> Self
Returns a new ModuleDescriptor instantiated by library path and optional semantic
version.
The semantic version is optional, as currently the assembler allows assembling artifacts without providing one.
Sourcepub fn set_version(&mut self, version: Version)
pub fn set_version(&mut self, version: Version)
Specify the version of this module
Sourcepub fn add_procedure(
&mut self,
name: ProcedureName,
digest: Word,
signature: Option<Arc<FunctionType>>,
attributes: AttributeSet,
)
pub fn add_procedure( &mut self, name: ProcedureName, digest: Word, signature: Option<Arc<FunctionType>>, attributes: AttributeSet, )
Adds a procedure to the module.
Sourcepub fn add_procedure_with_provenance(
&mut self,
name: ProcedureName,
digest: Word,
signature: Option<Arc<FunctionType>>,
attributes: AttributeSet,
source_root_id: Option<MastNodeId>,
source_debug_root_id: Option<u32>,
source_library_commitment: Option<Word>,
)
pub fn add_procedure_with_provenance( &mut self, name: ProcedureName, digest: Word, signature: Option<Arc<FunctionType>>, attributes: AttributeSet, source_root_id: Option<MastNodeId>, source_debug_root_id: Option<u32>, source_library_commitment: Option<Word>, )
Adds a procedure to the module with optional source provenance.
Sourcepub fn add_constant(&mut self, name: Ident, value: ConstantValue)
pub fn add_constant(&mut self, name: Ident, value: ConstantValue)
Adds a constant to the module.
Sourcepub fn add_submodule(&mut self, submodule: SubmoduleDecl)
pub fn add_submodule(&mut self, submodule: SubmoduleDecl)
Adds a submodule declaration to the module surface.
Sourcepub fn num_procedures(&self) -> usize
pub fn num_procedures(&self) -> usize
Returns the number of procedures in the module.
Sourcepub fn get_item_by_index(&self, index: ItemIndex) -> Option<&ItemInfo>
pub fn get_item_by_index(&self, index: ItemIndex) -> Option<&ItemInfo>
Returns the ItemInfo of the item at the provided index, if any.
Sourcepub fn get_item_index_by_name(&self, name: &str) -> Option<ItemIndex>
pub fn get_item_index_by_name(&self, name: &str) -> Option<ItemIndex>
Returns the ItemIndex of an item by its local name
Sourcepub fn get_procedure_by_name(&self, name: &str) -> Option<&ProcedureInfo>
pub fn get_procedure_by_name(&self, name: &str) -> Option<&ProcedureInfo>
Returns the procedure info for the procedure with the provided name, if any.
Sourcepub fn get_procedure_digest_by_name(&self, name: &str) -> Option<Word>
pub fn get_procedure_digest_by_name(&self, name: &str) -> Option<Word>
Returns the digest of the procedure with the provided name, if any.
Sourcepub fn items(&self) -> impl ExactSizeIterator<Item = (ItemIndex, &ItemInfo)>
pub fn items(&self) -> impl ExactSizeIterator<Item = (ItemIndex, &ItemInfo)>
Returns an iterator over the items in the module with their corresponding item index in the module.
Sourcepub fn submodules(&self) -> &[SubmoduleDecl]
pub fn submodules(&self) -> &[SubmoduleDecl]
Returns the declared submodules in this module surface.
Sourcepub fn procedures(&self) -> impl Iterator<Item = (ItemIndex, &ProcedureInfo)>
pub fn procedures(&self) -> impl Iterator<Item = (ItemIndex, &ProcedureInfo)>
Returns an iterator over the procedure infos in the module with their corresponding item index in the module.
Sourcepub fn procedure_digests(&self) -> impl Iterator<Item = Word> + '_
pub fn procedure_digests(&self) -> impl Iterator<Item = Word> + '_
Returns an iterator over the MAST roots of procedures defined in this module.
Sourcepub fn constants(&self) -> impl Iterator<Item = (ItemIndex, &ConstantInfo)>
pub fn constants(&self) -> impl Iterator<Item = (ItemIndex, &ConstantInfo)>
Access the constants associated with this module