pub enum HexErrorKind {
MissingDigits,
Invalid,
Overflow,
TooLong,
}Variants
MissingDigits
Expected two hex digits for every byte, but had fewer than that
Invalid
Valid hex-encoded integers are expected to come in sizes of 8, 16, or 64 digits, but the input consisted of an invalid number of digits.
Overflow
Occurs when a hex-encoded value overflows Felt::ORDER_U64, the maximum integral value
TooLong
Occurs when the hex-encoded value is > 64 digits