pub enum IntValue {
U8(u8),
U16(u16),
U32(u32),
Felt(Felt),
}Expand description
Represents one of the various types of values that have a hex-encoded representation in Miden Assembly source files.
Variants
U8(u8)
A tiny value
U16(u16)
A small value
U32(u32)
A u32 constant, typically represents a memory address
Felt(Felt)
A single field element, 8 bytes, encoded as 16 hex digits
Implementations
Sourceimpl IntValue
impl IntValue
pub fn as_int(&self) -> u64
Sourcepub fn as_canonical_u64(&self) -> u64
pub fn as_canonical_u64(&self) -> u64
Returns the value as a u64.
This is an alias for as_int that matches the Felt API,
allowing the generated grammar code to use a consistent method name.
pub fn checked_add(&self, rhs: Self) -> Option<Self>
pub fn checked_sub(&self, rhs: Self) -> Option<Self>
pub fn checked_mul(&self, rhs: Self) -> Option<Self>
pub fn checked_div(&self, rhs: Self) -> Option<Self>