pub fn parse_forms(source: Arc<SourceFile>) -> Result<Vec<Form>, ParsingError>Expand description
This is used in tests to parse source as a set of raw ast::Forms rather than as a
ast::Module.
NOTE: This does not run semantic analysis.
pub fn parse_forms(source: Arc<SourceFile>) -> Result<Vec<Form>, ParsingError>This is used in tests to parse source as a set of raw ast::Forms rather than as a
ast::Module.
NOTE: This does not run semantic analysis.