read_modules_from_root

Function read_modules_from_root 

pub fn read_modules_from_root(
    root: impl AsRef<Path>,
    namespace: Option<Arc<Path>>,
    kind: Option<ModuleKind>,
    source_manager: Arc<dyn SourceManager>,
    warnings_as_errors: bool,
) -> Result<(Box<Module>, Vec<Box<Module>>), Report>
Read the contents (modules) of this library from dir, returning any errors that occur while traversing the file system.

Errors may also be returned if traversal discovers issues with the modules, such as invalid names, etc.

Returns an iterator over all parsed modules.