ModuleParser

Struct ModuleParser 

pub struct ModuleParser { /* private fields */ }
This is a wrapper around the lower-level parser infrastructure which handles orchestrating all of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.

Implementations

Source

impl ModuleParser

pub fn new(kind: Option<ModuleKind>) -> Self

Construct a new parser for the given kind of ast::Module.

pub fn set_warnings_as_errors(&mut self, yes: bool)

Configure this parser so that any warning diagnostics are promoted to errors.

pub fn parse( &mut self, path: Option<&Path>, source: Arc<SourceFile>, source_manager: Arc<dyn SourceManager>, ) -> Result<Box<Module>, Report>

Parse a ast::Module from source, and give it the provided path.

If path is unset, then it must be derivable in one of two ways:

  1. From a namespace declaration in the module source
  2. Inferred as $exec from the presence of a begin .. end block in the module source

If neither is present, then an error will be raised. It can be fixed by simply providing path explicitly.

pub fn parse_file<P>( &mut self, path: Option<&Path>, file_path: P, source_manager: Arc<dyn SourceManager>, ) -> Result<Box<Module>, Report>
where P: AsRef<Path>,

Parse a ast::Module, name, from path.

pub fn parse_str( &mut self, path: Option<&Path>, source: impl ToString, source_manager: Arc<dyn SourceManager>, ) -> Result<Box<Module>, Report>

Parse a ast::Module, name, from source.