indent

Function indent 

pub fn indent(indent: u32, doc: Document) -> Document
Increase the indentation level of the given document by width.

The indentation level determines the number of spaces put after newlines.

NOTE: Indentation is applied following newlines, therefore, the first line of a document is not indented.