pub struct AnalysisContext { /* private fields */ }Expand description
This maintains the state for semantic analysis of a single Module.
Implementations
Sourceimpl AnalysisContext
impl AnalysisContext
pub fn new( source_file: Arc<SourceFile>, source_manager: Arc<dyn SourceManager>, ) -> Self
pub fn set_warnings_as_errors(&mut self, yes: bool)
pub fn warnings_as_errors(&self) -> bool
pub fn source_manager(&self) -> Arc<dyn SourceManager>
pub fn register_procedure_name(&mut self, name: ProcedureName)
pub fn register_imported_name(&mut self, name: Ident)
Sourcepub fn define_constant(&mut self, module: &mut Module, constant: Constant)
pub fn define_constant(&mut self, module: &mut Module, constant: Constant)
Define a new constant constant
Returns Err if a constant with the same name is already defined
Sourcepub fn register_constant(&mut self, constant: Constant)
pub fn register_constant(&mut self, constant: Constant)
Register a constant for semantic analysis without defining it in the module.
This is used for enum variants so we can fold discriminants without attempting to define the same constant twice.
Sourcepub fn simplify_constants(&mut self)
pub fn simplify_constants(&mut self)
Rewrite all constant declarations by performing const evaluation of their expressions.
This also has the effect of validating that the constant expressions themselves are valid.
Sourcepub fn get_constant(
&self,
name: &Ident,
) -> Result<&ConstantExpr, SemanticAnalysisError>
pub fn get_constant( &self, name: &Ident, ) -> Result<&ConstantExpr, SemanticAnalysisError>
Get the constant value bound to name
Returns Err if the symbol is undefined
pub fn error(&mut self, diagnostic: SemanticAnalysisError)
pub fn has_errors(&self) -> bool
pub fn has_failed(&mut self) -> Result<(), SyntaxError>
pub fn into_result(self) -> Result<(), SyntaxError>