pub struct SyntaxError {
pub source_file: Arc<SourceFile>,
pub errors: Vec<SemanticAnalysisError>,
}Expand description
The high-level error type for all semantic analysis errors.
This rolls up multiple errors into a single one, and as such, can emit many diagnostics at once. You should prefer to gather up errors and continue with analysis for as long as possible before returning an error of this type, so as to provide as much information to the user as possible, but there are cases where doing so would not be profitable - it is a judgement call.
The semantic analyzer does this though, and you can examine its implementation to see how we approach this during the semantic analysis phase specifically.
Fields
source_file: Arc<SourceFile>errors: Vec<SemanticAnalysisError>Trait Implementations
Sourceimpl Debug for SyntaxError
impl Debug for SyntaxError
Sourceimpl Diagnostic for SyntaxError
impl Diagnostic for SyntaxError
Sourcefn help(&self) -> Option<Box<dyn Display + '_>>
fn help(&self) -> Option<Box<dyn Display + '_>>
Additional help text related to this
Diagnostic. Do you have any
advice for the poor soul who’s just run into this issue?Additional related
Diagnostics.Sourcefn source_code(&self) -> Option<&dyn SourceCode>
fn source_code(&self) -> Option<&dyn SourceCode>
Source code to apply this
Diagnostic’s [Diagnostic::labels] to.fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn code<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
Unique diagnostic code that can be used to look up more information
about this
Diagnostic. Ideally also globally unique, and documented
in the toplevel crate’s documentation for easy searching. Rust path
format (foo::bar::baz) is recommended, but more classic codes like
E0123 or enums will work just fine.fn severity(&self) -> Option<Severity>
fn severity(&self) -> Option<Severity>
Diagnostic severity. This may be used by
ReportHandlers to change the display format
of this diagnostic. Read morefn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
fn url<'a>(&'a self) -> Option<Box<dyn Display + 'a>>
URL to visit for a more detailed explanation/help about this
Diagnostic.fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
fn labels(&self) -> Option<Box<dyn Iterator<Item = LabeledSpan> + '_>>
Labels to apply to this
Diagnostic’s [Diagnostic::source_code]fn diagnostic_source<'a>(&'a self) -> Option<&'a dyn Diagnostic>
fn diagnostic_source<'a>(&'a self) -> Option<&'a dyn Diagnostic>
The cause of the error.
Sourceimpl Display for SyntaxError
impl Display for SyntaxError
Sourceimpl Error for SyntaxError
impl Error for SyntaxError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()