VerifyInvokeTargets

Struct VerifyInvokeTargets 

pub struct VerifyInvokeTargets<'a> { /* private fields */ }
This visitor visits every exec, call, syscall, and procref, and ensures that the invocation target for that call is resolvable to the extent possible within the current module’s context.

This means that any reference to an external module must have a corresponding import, and that the invocation kind is valid in the current module.

We attempt to apply as many call-related validations as we can here, however we are limited until later stages of compilation on what we can know in the context of a single module. As a result, more complex analyses are reserved until assembly.

Implementations

Source

impl<'a> VerifyInvokeTargets<'a>

pub fn new( analyzer: &'a mut AnalysisContext, module: &'a mut Module, procedures: &'a BTreeSet<Ident>, current_procedure: Option<ProcedureName>, ) -> Self