#[repr(u8)]pub enum Op {
If {
span: SourceSpan,
then_blk: Block,
else_blk: Block,
},
While {
span: SourceSpan,
body: Block,
},
DoWhile {
span: SourceSpan,
body: Block,
condition: Block,
},
Repeat {
span: SourceSpan,
count: Immediate<u32>,
body: Block,
},
Inst(Span<Instruction>),
}Expand description
Represents the Miden Assembly instruction set syntax
This is separate from Instruction in order to distinguish control flow instructions and instructions with block regions from the rest.
Variants
If
Represents a conditional branch
Can be either if..end, or if..else..end.
Fields
span: SourceSpanWhile
Represents a head-controlled loop (while.true..end).
DoWhile
Represents a tail-controlled loop (do..while..end).
The body always executes at least once; the condition block is then evaluated and must
leave a boolean on top of the stack. The loop re-iterates while that boolean is 1 and
exits when it is 0.
Repeat
Represents a counter-controlled loop.
NOTE: The iteration count must be known at compile-time, so this is not used for general
for-style loops where the iteration count is dynamic.
Also, it may be either a literal value or constant name (e.g. add.1 or add.CONST)
Inst(Span<Instruction>)
A primitive operation, e.g. add