Module parser

Module parser 

Structs

ModuleParser
This is a wrapper around the lower-level parser infrastructure which handles orchestrating all of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.
WordValue

Enums

BinErrorKind
HexErrorKind
IntValue
Represents one of the various types of values that have a hex-encoded representation in Miden Assembly source files.
LiteralErrorKind
ParsingError
PushValue

Functions

parse_inline_masm
This is like parse_forms, but for parsing the content of inline MASM blocks in languages like Rust.
read_modules_from_root
Read the contents (modules) of this library from dir, returning any errors that occur while traversing the file system.
walk_module_tree