Structs
- Module
Parser - This is a wrapper around the lower-level parser infrastructure which handles orchestrating all of the pieces needed to parse a ast::Module from source, and run semantic analysis on it.
- Word
Value
Enums
- BinError
Kind - HexError
Kind - IntValue
- Represents one of the various types of values that have a hex-encoded representation in Miden Assembly source files.
- Literal
Error Kind - Parsing
Error - Push
Value
Functions
- parse_
inline_ masm - This is like
parse_forms, but for parsing the content of inline MASM blocks in languages like Rust. - read_
modules_ from_ root - Read the contents (modules) of this library from
dir, returning any errors that occur while traversing the file system. - walk_
module_ tree