pub fn parse_inline_masm(
source: Arc<SourceFile>,
bounds: Option<SourceSpan>,
interned: &mut BTreeSet<Arc<str>>,
) -> Result<Block, Report>Expand description
This is like parse_forms, but for parsing the content of inline MASM blocks in languages like
Rust.
Inline MASM is parsed as an ast::Block, as if it was the body of a procedure definition. This means that top-level items such as imports and constant declarations are not allowed.
An optional span can be provided, in which case only the contents of the span are parsed as the inline MASM.